@@ -1,9 +1,16 @@
 from datetime import date, datetime
 from pathlib import Path
 from typing import Any, Callable, Dict, IO, List, Tuple, Union, Optional
-
 from coinmetrics.constants import PagingFrom
 
+try:
+    import pandas as pd  # type: ignore
+
+    DataFrameType = pd.core.frame.DataFrame
+except ImportError:
+    pd = None
+    DataFrameType = Any
+
 FilePathOrBuffer = Union[str, Path, IO[str], IO[bytes], None]
 DataReturnType = Dict[str, Union[str, Dict[str, str], List[Dict[str, Any]]]]
 DataRetrievalFuncType = Callable[[str, Dict[str, Any]], DataReturnType]
