@@ -466,7 +466,9 @@ class CoinMetricsDataExporter:
 
     @retry((socket.gaierror, HTTPError), retries=5, wait_time_between_retries=5)
     def _send_request(self, actual_url: str, stream: bool = False) -> Response:
-        response = self._session.get(actual_url, verify=self._verify_ssl_certs, auth=self._auth, stream=stream)
+        response = self._session.get(
+            actual_url, verify=self._verify_ssl_certs, auth=self._auth, stream=stream
+        )
         if response.status_code == 403 or response.status_code == 401:
             raise CoinMetricsUnauthorizedException(response=response)
         if response.status_code != 200:
